==> citrus-ssh-4.0.0-sources.jar: org/citrusframework/model/config/ssh/SshServerModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ssh;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="auto-start" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="host-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user-home-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="allowed-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="debug-logging" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "server")
public class SshServerModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "port")
    protected String port;
    @XmlAttribute(name = "auto-start")
    protected Boolean autoStart;
    @XmlAttribute(name = "host-key-path")
    protected String hostKeyPath;
    @XmlAttribute(name = "user-home-path")
    protected String userHomePath;
    @XmlAttribute(name = "user")
    protected String user;
    @XmlAttribute(name = "password")
    protected String password;
    @XmlAttribute(name = "allowed-key-path")
    protected String allowedKeyPath;
    @XmlAttribute(name = "endpoint-adapter")
    protected String endpointAdapter;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "debug-logging")
    protected Boolean debugLogging;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der port-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Ruft den Wert der autoStart-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoStart() {
        return autoStart;
    }

    /**
     * Legt den Wert der autoStart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoStart(Boolean value) {
        this.autoStart = value;
    }

    /**
     * Ruft den Wert der hostKeyPath-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHostKeyPath() {
        return hostKeyPath;
    }

    /**
     * Legt den Wert der hostKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHostKeyPath(String value) {
        this.hostKeyPath = value;
    }

    /**
     * Ruft den Wert der userHomePath-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUserHomePath() {
        return userHomePath;
    }

    /**
     * Legt den Wert der userHomePath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUserHomePath(String value) {
        this.userHomePath = value;
    }

    /**
     * Ruft den Wert der user-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser() {
        return user;
    }

    /**
     * Legt den Wert der user-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser(String value) {
        this.user = value;
    }

    /**
     * Ruft den Wert der password-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPassword() {
        return password;
    }

    /**
     * Legt den Wert der password-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPassword(String value) {
        this.password = value;
    }

    /**
     * Ruft den Wert der allowedKeyPath-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAllowedKeyPath() {
        return allowedKeyPath;
    }

    /**
     * Legt den Wert der allowedKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAllowedKeyPath(String value) {
        this.allowedKeyPath = value;
    }

    /**
     * Ruft den Wert der endpointAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointAdapter() {
        return endpointAdapter;
    }

    /**
     * Legt den Wert der endpointAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointAdapter(String value) {
        this.endpointAdapter = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der debugLogging-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDebugLogging() {
        return debugLogging;
    }

    /**
     * Legt den Wert der debugLogging-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDebugLogging(Boolean value) {
        this.debugLogging = value;
    }

}

==> citrus-ssh-4.1.1-sources.jar: org/citrusframework/model/config/ssh/SshServerModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ssh;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="auto-start" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="host-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user-home-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="allowed-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="debug-logging" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "server")
public class SshServerModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    /**
     * Port to listen to. Default is 22
     * 
     */
    @XmlAttribute(name = "port")
    protected String port;
    /**
     * Whether to start this SSH server automatically. Default is true. If set to false,
     *                 a test action is responsible for starting/stopping the server
     * 
     */
    @XmlAttribute(name = "auto-start")
    protected Boolean autoStart;
    /**
     * Path to PEM encoded key pair (public and private key) which is used as host key.
     *                 By default, a standard, fixed keypair is used.
     * 
     */
    @XmlAttribute(name = "host-key-path")
    protected String hostKeyPath;
    /**
     * Path to user home directory. If not set ${user.dir}/target/{serverName}/home/{user} is used by default.
     * 
     */
    @XmlAttribute(name = "user-home-path")
    protected String userHomePath;
    /**
     * User which is allowed to connect.
     * 
     */
    @XmlAttribute(name = "user")
    protected String user;
    /**
     * Password for authenticating the user.
     * 
     */
    @XmlAttribute(name = "password")
    protected String password;
    /**
     * Path to a public key in PEM format. If prefixed with 'classpath:' it is read
     *                 as a resource.
     * 
     */
    @XmlAttribute(name = "allowed-key-path")
    protected String allowedKeyPath;
    @XmlAttribute(name = "endpoint-adapter")
    protected String endpointAdapter;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "debug-logging")
    protected Boolean debugLogging;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Port to listen to. Default is 22
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPort()
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Whether to start this SSH server automatically. Default is true. If set to false,
     *                 a test action is responsible for starting/stopping the server
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoStart() {
        return autoStart;
    }

    /**
     * Legt den Wert der autoStart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     * @see #isAutoStart()
     */
    public void setAutoStart(Boolean value) {
        this.autoStart = value;
    }

    /**
     * Path to PEM encoded key pair (public and private key) which is used as host key.
     *                 By default, a standard, fixed keypair is used.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHostKeyPath() {
        return hostKeyPath;
    }

    /**
     * Legt den Wert der hostKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getHostKeyPath()
     */
    public void setHostKeyPath(String value) {
        this.hostKeyPath = value;
    }

    /**
     * Path to user home directory. If not set ${user.dir}/target/{serverName}/home/{user} is used by default.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUserHomePath() {
        return userHomePath;
    }

    /**
     * Legt den Wert der userHomePath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getUserHomePath()
     */
    public void setUserHomePath(String value) {
        this.userHomePath = value;
    }

    /**
     * User which is allowed to connect.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser() {
        return user;
    }

    /**
     * Legt den Wert der user-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getUser()
     */
    public void setUser(String value) {
        this.user = value;
    }

    /**
     * Password for authenticating the user.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPassword() {
        return password;
    }

    /**
     * Legt den Wert der password-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPassword()
     */
    public void setPassword(String value) {
        this.password = value;
    }

    /**
     * Path to a public key in PEM format. If prefixed with 'classpath:' it is read
     *                 as a resource.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAllowedKeyPath() {
        return allowedKeyPath;
    }

    /**
     * Legt den Wert der allowedKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getAllowedKeyPath()
     */
    public void setAllowedKeyPath(String value) {
        this.allowedKeyPath = value;
    }

    /**
     * Ruft den Wert der endpointAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointAdapter() {
        return endpointAdapter;
    }

    /**
     * Legt den Wert der endpointAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointAdapter(String value) {
        this.endpointAdapter = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der debugLogging-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDebugLogging() {
        return debugLogging;
    }

    /**
     * Legt den Wert der debugLogging-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDebugLogging(Boolean value) {
        this.debugLogging = value;
    }

}
